@@ -6,8 +6,7 @@ class TestingCategorizedObjectAdapter(CategorizedObjectAdapter):
 
     def can_view(self):
         """Return False if element is confidential."""
-        obj = self.brain._unrestrictedGetObject()
-        if obj.confidential:
+        if self.categorized_obj.confidential:
             return False
         else:
             return True
